/***************************************************************************
 *   Copyright (C) 2008 by Christoph Burger-Scheidlin                      *
 *   mail@christoph.burger-scheidlin.name                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef COUNTDOWN_H
#define COUNTDOWN_H

#include <Plasma/Applet>
#include <Plasma/DataEngine>

#include "ui_countdownConfig.h"

class KDialog;

class Countdown : public Plasma::Applet
{
	Q_OBJECT
	public:
		Countdown(QObject *parent, const QVariantList &args);
		~Countdown();

		void init();
		void paintInterface(QPainter *painter,
			const QStyleOptionGraphicsItem *option,
			const QRect& contentsRect);
		void constraintsUpdated(Plasma::Constraints);

	public slots:
		void dataUpdated(const QString &source, const Plasma::DataEngine::Data &data);
		void showConfigurationInterface();

	protected slots:
		void configAccepted();
		QDateTime targetTimeInUTC( const QDateTime& dateTime, const QString& timezone );

	private:
	        QRect preparePainter(QPainter *p, const QRect &rect, const QFont &font, const QString &text);
		QString determineDisplayString( int seconds );

		QFont m_font;
		QColor m_color;
		QColor m_negativeColor;
		bool m_fontBold;
		bool m_fontItalic;
		bool m_negative;

		QString m_displayString;
		QString m_lastDisplayString;

		QString m_timezone;
		QDateTime m_targetDateTime;
		Plasma::IntervalAlignment m_currentAlignment;

		KDialog *m_configDialog;
		Ui::countdownConfig ui;
};

K_EXPORT_PLASMA_APPLET(countdown, Countdown);
#endif //COUNTDOWN_H
